#!/bin/bash

USERSPACE_TAR=$1
VAAPI_TAR=$2
README_FILE=$3

USERSPACE_VERSION=`echo $USERSPACE_TAR | sed 's/.*v\([.[:digit:]]*\).*/\1/'`
VAAPI_VERSION=`echo $VAAPI_TAR | sed 's/.*v\([.[:digit:]]*\).*/\1/'`

if [[ "$USERSPACE_VERSION" != "$VAAPI_VERSION" ]]; then
    echo "ERROR: Package versions do not match!"
    exit 1
fi

PACKAGE_NAME=cdv-video-$USERSPACE_VERSION
USERSPACE_DIRNAME=cedarview-userspace-$USERSPACE_VERSION
VAAPI_DIRNAME=cedarview-vaapi-$USERSPACE_VERSION

BASEDIR=/tmp
WORKINGDIR=$BASEDIR/$PACKAGE_NAME
USERSPACEDIR=$WORKINGDIR/$USERSPACE_DIRNAME
VAAPIDIR=$WORKINGDIR/$VAAPI_DIRNAME
SCRIPTDIR=$WORKINGDIR/scripts

mkdir -p $WORKINGDIR
mkdir -p $USERSPACEDIR
mkdir -p $VAAPIDIR
mkdir -p $SCRIPTDIR

# Extract files into working dir
tar xf $USERSPACE_TAR -C $USERSPACEDIR
tar xf $VAAPI_TAR -C $VAAPIDIR
cp $0 $SCRIPTDIR
cp $README_FILE $WORKINGDIR/README

# Create Makefile
echo "#cdv-video Makefile
#Copyright 2013 Timesys Corporation

all:

install: install-userspace install-vaapi

install-userspace:
	mkdir -p \$(DESTDIR)/usr/
	mkdir -p \$(DESTDIR)/etc/
	cp -r ${USERSPACE_DIRNAME}/usr/* \$(DESTDIR)/usr/
	install ${USERSPACE_DIRNAME}/etc/powervr.ini \$(DESTDIR)/etc/
	install ${USERSPACE_DIRNAME}/etc/pvr-version.txt \$(DESTDIR)/etc/

install-vaapi:
	mkdir -p \$(DESTDIR)/usr/
	mkdir -p \$(DESTDIR)/lib/
	cp -r ${VAAPI_DIRNAME}/usr/* \$(DESTDIR)/usr/
	cp -r ${VAAPI_DIRNAME}/lib/* \$(DESTDIR)/lib/

clean:

PHONY: all install install-vaapi install-userspace clean
" > $WORKINGDIR/Makefile

tar cjf $PACKAGE_NAME.tar.bz2 -C $BASEDIR $PACKAGE_NAME

rm -rf $WORKINGDIR
